==> jc-1.4.0.tar.gz: javax/print/attribute/IntegerSyntax.h <==
// public abstract class javax.print.attribute.IntegerSyntax

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 18f59a31666d35f javax_print_attribute_IntegerSyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_IntegerSyntax_H_
#define _JC_javax_print_attribute_IntegerSyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_IntegerSyntax$sub_refs	_jc_javax_print_attribute_IntegerSyntax$sub_refs;
typedef struct _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	_jc_javax_print_attribute_IntegerSyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_IntegerSyntax$refs	_jc_javax_print_attribute_IntegerSyntax$refs;
typedef struct _jc_javax_print_attribute_IntegerSyntax$nonrefs	_jc_javax_print_attribute_IntegerSyntax$nonrefs;
typedef struct _jc_javax_print_attribute_IntegerSyntax$object	_jc_javax_print_attribute_IntegerSyntax$object;

typedef const struct _jc_javax_print_attribute_IntegerSyntax$vmethods	_jc_javax_print_attribute_IntegerSyntax$vmethods;
typedef const struct _jc_javax_print_attribute_IntegerSyntax$vtable	_jc_javax_print_attribute_IntegerSyntax$vtable;
typedef const struct _jc_javax_print_attribute_IntegerSyntax$vtype	_jc_javax_print_attribute_IntegerSyntax$vtype;

// Constructors
extern void _jc_javax_print_attribute_IntegerSyntax$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *, jint);
extern void _jc_javax_print_attribute_IntegerSyntax$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *, jint, jint, jint);

// Virtual methods
extern jboolean _jc_javax_print_attribute_IntegerSyntax$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_javax_print_attribute_IntegerSyntax$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *);
extern jint _jc_javax_print_attribute_IntegerSyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_IntegerSyntax$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_IntegerSyntax$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_IntegerSyntax$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_print_attribute_IntegerSyntax$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_print_attribute_IntegerSyntax$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_attribute_IntegerSyntax$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *, struct _jc_java_lang_Object$object *);
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *);
};

// Vtable
struct _jc_javax_print_attribute_IntegerSyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_IntegerSyntax$vmethods	javax_print_attribute_IntegerSyntax;
};

// Vtype
struct _jc_javax_print_attribute_IntegerSyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_IntegerSyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_IntegerSyntax$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_IntegerSyntax$refs {
    _jc_javax_print_attribute_IntegerSyntax$sub_refs	javax_print_attribute_IntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_IntegerSyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	javax_print_attribute_IntegerSyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_IntegerSyntax$object {
	_jc_javax_print_attribute_IntegerSyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_IntegerSyntax$vtype	*vtype;
	_jc_javax_print_attribute_IntegerSyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_IntegerSyntax$vtype _jc_javax_print_attribute_IntegerSyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_IntegerSyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_IntegerSyntax$class_object;

#endif	/* _JC_javax_print_attribute_IntegerSyntax_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/IntegerSyntax.h <==
// public abstract class javax.print.attribute.IntegerSyntax

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 18f59a31666d35f javax_print_attribute_IntegerSyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_IntegerSyntax_H_
#define _JC_javax_print_attribute_IntegerSyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_IntegerSyntax$sub_refs	_jc_javax_print_attribute_IntegerSyntax$sub_refs;
typedef struct _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	_jc_javax_print_attribute_IntegerSyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_IntegerSyntax$refs	_jc_javax_print_attribute_IntegerSyntax$refs;
typedef struct _jc_javax_print_attribute_IntegerSyntax$nonrefs	_jc_javax_print_attribute_IntegerSyntax$nonrefs;
typedef struct _jc_javax_print_attribute_IntegerSyntax$object	_jc_javax_print_attribute_IntegerSyntax$object;

typedef const struct _jc_javax_print_attribute_IntegerSyntax$vmethods	_jc_javax_print_attribute_IntegerSyntax$vmethods;
typedef const struct _jc_javax_print_attribute_IntegerSyntax$vtable	_jc_javax_print_attribute_IntegerSyntax$vtable;
typedef const struct _jc_javax_print_attribute_IntegerSyntax$vtype	_jc_javax_print_attribute_IntegerSyntax$vtype;

// Constructors
extern void _jc_javax_print_attribute_IntegerSyntax$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_IntegerSyntax$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_IntegerSyntax$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_print_attribute_IntegerSyntax$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_print_attribute_IntegerSyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_IntegerSyntax$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_IntegerSyntax$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_IntegerSyntax$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_print_attribute_IntegerSyntax$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_print_attribute_IntegerSyntax$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_attribute_IntegerSyntax$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_attribute_IntegerSyntax$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_IntegerSyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_IntegerSyntax$vmethods	javax_print_attribute_IntegerSyntax;
};

// Vtype
struct _jc_javax_print_attribute_IntegerSyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_IntegerSyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_IntegerSyntax$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_IntegerSyntax$refs {
    _jc_javax_print_attribute_IntegerSyntax$sub_refs	javax_print_attribute_IntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_IntegerSyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	javax_print_attribute_IntegerSyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_IntegerSyntax$object {
	_jc_javax_print_attribute_IntegerSyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_IntegerSyntax$vtype	*vtype;
	_jc_javax_print_attribute_IntegerSyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_IntegerSyntax$vtype _jc_javax_print_attribute_IntegerSyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_IntegerSyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_IntegerSyntax$class_object;

#endif	/* _JC_javax_print_attribute_IntegerSyntax_H_ */
